# myalbum-dl
A command-line tool written in Python for downloading albums from MyAlbum

<img src="https://raw.githubusercontent.com/GBS3/myalbum-dl/main/media/terminal.gif">

# Installation
In order to install the tool, run the following in your terminal:

```sh
$ pip install myalbum-dl
```

# Usage
Once `myalbum-dl` is installed, all you need to do is run the following in your terminal to use it:

```sh
$ myalbum-dl <URL>
```

For example:

```sh
$ myalbum-dl https://myalbum.com/album/uRCYu2bHECn7
```